┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/bookmarkselector.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/bookmarkselector.h')
-rw-r--r--src/bookmarkselector.h9
1 files changed, 4 insertions, 5 deletions
diff --git a/src/bookmarkselector.h b/src/bookmarkselector.h
index c662618ec..50fc2e3e5 100644
--- a/src/bookmarkselector.h
+++ b/src/bookmarkselector.h
@@ -1,6 +1,5 @@
/***************************************************************************
- * Copyright (C) 2006 by Peter Penz *
+ * Copyright (C) 2006 by Peter Penz ([email protected]) *
* *
* This program is free software; you can redistribute it and/or modify *
* it under the terms of the GNU General Public License as published by *
@@ -35,7 +34,6 @@ class KUrl;
* inside the bookmark selector.
*
* @see UrlNavigator
- * @author Peter Penz <[email protected]>
*/
class BookmarkSelector : public UrlButton
{
@@ -74,9 +72,9 @@ public:
signals:
/**
* Is send when a bookmark has been activated by the user.
* @param index Index of the selected bookmark.
*/
- void bookmarkActivated(int index);
+ void bookmarkActivated(const KUrl& url);
protected:
/**
@@ -94,6 +92,7 @@ private slots:
private:
int m_selectedIndex;
+ UrlNavigator* m_urlNavigator;
Q3PopupMenu* m_bookmarksMenu;
};
@@ -74,9 +72,9 @@ public:
/**
* Is send when a bookmark has been activated by the user.
- * @param index Index of the selected bookmark.
+ * @param url URL of the selected bookmark.
*/